This is an automated email from the ASF dual-hosted git repository.

jerpelea pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-nuttx.git


The following commit(s) were added to refs/heads/master by this push:
     new 3adadbe  arch/stm32: Fix nxstyle errors
3adadbe is described below

commit 3adadbe5d70ce7cb5edc15c0e75e37fd01e57587
Author: Nathan Hartman <59230071+hartmannat...@users.noreply.github.com>
AuthorDate: Mon Dec 14 10:32:00 2020 -0500

    arch/stm32: Fix nxstyle errors
    
    arch/arm/src/stm32/stm32_usbhost.h:
    
        * Fix nxstyle errors.
---
 arch/arm/src/stm32/stm32_usbhost.h | 67 +++++++++++++++++++-------------------
 1 file changed, 34 insertions(+), 33 deletions(-)

diff --git a/arch/arm/src/stm32/stm32_usbhost.h 
b/arch/arm/src/stm32/stm32_usbhost.h
index c8348c0..d4b2c32 100644
--- a/arch/arm/src/stm32/stm32_usbhost.h
+++ b/arch/arm/src/stm32/stm32_usbhost.h
@@ -1,4 +1,4 @@
-/************************************************************************************
+/****************************************************************************
  * arch/arm/src/stm32/stm32_usbhost.h
  *
  *   Copyright (C) 2012, 2014 Gregory Nutt. All rights reserved.
@@ -31,14 +31,14 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- 
************************************************************************************/
+ ****************************************************************************/
 
 #ifndef __ARCH_ARM_SRC_STM32_STM32_USBHOST_H
 #define __ARCH_ARM_SRC_STM32_STM32_USBHOST_H
 
-/************************************************************************************
+/****************************************************************************
  * Included Files
- 
************************************************************************************/
+ ****************************************************************************/
 
 #include <nuttx/config.h>
 #include <nuttx/usb/usbhost.h>
@@ -49,16 +49,17 @@
 #include "hardware/stm32fxxxxx_otgfs.h"
 #include "hardware/stm32_otghs.h"
 
-#if (defined(CONFIG_STM32_OTGFS) || defined(CONFIG_STM32_OTGHS)) && 
defined(CONFIG_STM32_USBHOST)
+#if (defined(CONFIG_STM32_OTGFS) || defined(CONFIG_STM32_OTGHS)) && \
+    defined(CONFIG_STM32_USBHOST)
 
-/************************************************************************************
+/****************************************************************************
  * Public Types
- 
************************************************************************************/
+ ****************************************************************************/
 
 #ifdef HAVE_USBHOST_TRACE
 enum usbhost_trace1codes_e
 {
-  __TRACE1_BASEVALUE = 0,           /* This will force the first value to be 1 
*/
+  __TRACE1_BASEVALUE = 0,            /* This will force the first value to be 
1 */
 
 #ifdef CONFIG_STM32_OTGFS
 
@@ -80,7 +81,7 @@ enum usbhost_trace1codes_e
   OTGFS_VTRACE1_GINT_PTXFE,          /* OTGFS Handle the periodic TxFIFO empty 
interrupt */
   OTGFS_VTRACE1_GINT_HC,             /* OTGFS Handle the host channels 
interrupt */
   OTGFS_VTRACE1_GINT_HPRT,           /* OTGFS Handle the host port interrupt */
-  OTGFS_VTRACE1_GINT_HPRT_POCCHNG,   /* OTGFS  HPRT: Port Over-Current Change*/
+  OTGFS_VTRACE1_GINT_HPRT_POCCHNG,   /* OTGFS  HPRT: Port Over-Current Change 
*/
   OTGFS_VTRACE1_GINT_HPRT_PCDET,     /* OTGFS  HPRT: Port Connect Detect */
   OTGFS_VTRACE1_GINT_HPRT_PENCHNG,   /* OTGFS  HPRT: Port Enable Changed */
   OTGFS_VTRACE1_GINT_HPRT_LSDEV,     /* OTGFS  HPRT: Low Speed Device 
Connected */
@@ -113,7 +114,7 @@ enum usbhost_trace1codes_e
   OTGHS_VTRACE1_GINT_PTXFE,          /* OTGHS Handle the periodic TxFIFO empty 
interrupt */
   OTGHS_VTRACE1_GINT_HC,             /* OTGHS Handle the host channels 
interrupt */
   OTGHS_VTRACE1_GINT_HPRT,           /* OTGHS Handle the host port interrupt */
-  OTGHS_VTRACE1_GINT_HPRT_POCCHNG,   /* OTGHS  HPRT: Port Over-Current Change*/
+  OTGHS_VTRACE1_GINT_HPRT_POCCHNG,   /* OTGHS  HPRT: Port Over-Current Change 
*/
   OTGHS_VTRACE1_GINT_HPRT_PCDET,     /* OTGHS  HPRT: Port Connect Detect */
   OTGHS_VTRACE1_GINT_HPRT_PENCHNG,   /* OTGHS  HPRT: Port Enable Changed */
   OTGHS_VTRACE1_GINT_HPRT_LSDEV,     /* OTGHS  HPRT: Low Speed Device 
Connected */
@@ -201,11 +202,11 @@ enum usbhost_trace1codes_e
 
 #endif
 
-/************************************************************************************
- * Public Functions
- 
************************************************************************************/
-/*
- * STM32 USB OTG FS Host Driver Support
+/****************************************************************************
+ * Public Function Prototypes
+ ****************************************************************************/
+
+/* STM32 USB OTG FS Host Driver Support
  *
  * Pre-requisites
  *
@@ -240,10 +241,6 @@ enum usbhost_trace1codes_e
  *    debug.  Depends on CONFIG_DEBUG_FEATURES.
  */
 
-/************************************************************************************
- * Public Functions
- 
************************************************************************************/
-
 #ifndef __ASSEMBLY__
 
 #undef EXTERN
@@ -255,33 +252,37 @@ extern "C"
 #define EXTERN extern
 #endif
 
-/***********************************************************************************
+/****************************************************************************
  * Name: stm32_usbhost_vbusdrive
  *
  * Description:
- *   Enable/disable driving of VBUS 5V output.  This function must be provided 
be
  *   each platform that implements the STM32 OTG FS host interface
  *
- *   "On-chip 5 V VBUS generation is not supported. For this reason, a charge 
pump
- *    or, if 5 V are available on the application board, a basic power switch, 
must
- *    be added externally to drive the 5 V VBUS line. The external charge pump 
can
- *    be driven by any GPIO output. When the application decides to power on 
VBUS
- *    using the chosen GPIO, it must also set the port power bit in the host 
port
- *    control and status register (PPWR bit in OTG_FS_HPRT).
+ *   "On-chip 5 V VBUS generation is not supported. For this reason, a
+ *    charge pump or, if 5 V are available on the application board, a basic
+ *    power switch, must be added externally to drive the 5 V VBUS line. The
+ *    external charge pump can be driven by any GPIO output. When the
+ *    application decides to power on VBUS using the chosen GPIO, it must
+ *    also set the port power bit in the host port control and status
+ *    register (PPWR bit in OTG_FS_HPRT).
  *
- *   "The application uses this field to control power to this port, and the 
core
- *    clears this bit on an overcurrent condition."
+ *   "The application uses this field to control power to this port, and the
+ *    core clears this bit on an overcurrent condition."
  *
  * Input Parameters:
- *   iface - For future growth to handle multiple USB host interface.  Should 
be zero.
+ *   iface  - For future growth to handle multiple USB host interface.
+ *            Should be zero.
  *   enable - true: enable VBUS power; false: disable VBUS power
  *
  * Returned Value:
  *   None
  *
- 
***********************************************************************************/
+ ****************************************************************************/
 
-#if defined(CONFIG_STM32_OTGFS_VBUS_CONTROL) || 
defined(CONFIG_STM32_OTGHS_VBUS_CONTROL)
+#if defined(CONFIG_STM32_OTGFS_VBUS_CONTROL) || \
+    defined(CONFIG_STM32_OTGHS_VBUS_CONTROL)
 void stm32_usbhost_vbusdrive(int iface, bool enable);
 #endif
 
@@ -255,33 +252,37 @@ extern "C"
be
- *   each platform that implements the STM32 OTG FS host interface
+ *   Enable/disable driving of VBUS 5V output.  This function must be
+ *   provided be each platform that implements the STM32 OTG FS host
+ *   interface.
  *

Reply via email to